@@ -6,11 +6,12 @@ use lib "$FindBin::Bin/../lib";
 use Module::CPANTS::Generator::Files;
 use Module::CPANTS::Generator::ModuleInfo;
 use Module::CPANTS::Generator::Prereq;
+use Module::CPANTS::Generator::Testers;
 use Module::CPANTS::Generator::Unpack;
 use Storable;
 use Template;
 
-my $version = "0.004";
+my $version = "0.005";
 
 my $unpacked = "$FindBin::Bin/../unpacked/";
 
@@ -27,6 +28,11 @@ if (-d $unpacked) {
   $u->unpack;
 }
 
+print "* Generating CPAN testers info...\n";
+my $t = Module::CPANTS::Generator::Testers->new;
+$t->directory($unpacked);
+#$t->generate;
+
 print "* Generating module info...\n";
 my $m = Module::CPANTS::Generator::ModuleInfo->new;
 $m->cpanplus($cpanplus);
